/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.aggregation.extern;

import java.util.concurrent.ExecutionException;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Component;

import de.ozgcloud.aggregation.Aggregation;
import de.ozgcloud.aggregation.AggregationDataLoader;
import de.ozgcloud.aggregation.transformation.AggregationMapping;
import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Component
@ConditionalOnProperty("grpc.client.aggregation-manager-server.address")
@RequiredArgsConstructor
@Log4j2
public class AggregationDataRemoteLoader implements AggregationDataLoader {

	private final AggregationDataRemoteService service;

	@Override
	public void loadIntoTarget(Aggregation aggregation) {
		try {
			service.sendAggregationData(aggregation).get();
		} catch (InterruptedException e) {
			Thread.currentThread().interrupt();
			throw new TechnicalException("Waiting for sending aggregation data to complete was interrupted.", e);
		} catch (ExecutionException e) {
			throw new TechnicalException("Error on sending aggregation data.", e);
		}
	}

	@Override
	public AggregationMapping.Scope getScope() {
		return AggregationMapping.Scope.EXTERN;
	}

}
