/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.aggregation.transformation;

import java.util.List;

import jakarta.validation.Valid;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Builder;
import lombok.Getter;
import lombok.Singular;
import lombok.ToString;

@Getter
@Builder
@ToString
public class AggregationMapping {

	@NotBlank
	private String name;
	@NotNull
	@Valid
	private FormIdentifier formIdentifier;

	@Singular
	@Valid
	private List<FieldMapping> fieldMappings;
	private String parent;
	private Status status;
	private Scope scope;

	public enum Status {
		AUSSTEHEND, FREIGEGEBEN, ZURUECKGEHALTEN;
	}

	public enum Scope {
		EXTERN, INTERN;
	}

	@Getter
	@Builder
	public static class FormIdentifier {
		@NotBlank
		private String formEngineName;
		@NotBlank
		private String formId;
	}

	@Getter
	@Builder
	public static class FieldMapping {
		@NotBlank
		private String sourcePath;
		@NotBlank
		private String targetPath;
	}
}
