/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.aggregation.extern;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.aggregation.data.GrpcObject;
import de.ozgcloud.aggregation.warehouse.DocumentEntryTestFactory;

class GrpcAggregationDataMapperTest {

	private final GrpcAggregationDataMapper mapper = Mappers.getMapper(GrpcAggregationDataMapper.class);

	@Nested
	class TestToGrpcAggregationData {

		@Test
		void shouldMapId() {
			var grpcData = mapper.toGrpcAggregationData(DocumentEntryTestFactory.create());

			assertThat(grpcData.getId()).isEqualTo(DocumentEntryTestFactory.ID);
		}

		@Test
		void shouldMapStatus() {
			var grpcData = mapper.toGrpcAggregationData(DocumentEntryTestFactory.create());

			assertThat(grpcData.getStatus()).isEqualTo(DocumentEntryTestFactory.STATUS);
		}

		@Test
		void shouldMapEingangDatum() {
			var grpcData = mapper.toGrpcAggregationData(DocumentEntryTestFactory.create());

			assertThat(grpcData.getEingangDatum()).isEqualTo(DocumentEntryTestFactory.EINGANGSDATUM.toString());
		}

		@Test
		void shouldMapVorgangName() {
			var grpcData = mapper.toGrpcAggregationData(DocumentEntryTestFactory.create());

			assertThat(grpcData.getVorgangName()).isEqualTo(DocumentEntryTestFactory.VORGANG_NAME);
		}

		@Test
		void shouldHaveDefaultPayload() {
			var grpcData = mapper.toGrpcAggregationData(DocumentEntryTestFactory.create());

			assertThat(grpcData.getPayload()).isEqualTo(GrpcObject.getDefaultInstance());
		}
	}
}
