/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.aggregation.warehouse;

import static org.assertj.core.api.Assertions.*;

import java.util.List;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;

import de.ozgcloud.aggregation.AggregationDataLoader;
import de.ozgcloud.aggregation.AggregationDataLoaderRegistry;
import de.ozgcloud.aggregation.transformation.AggregationMapping;
import de.ozgcloud.common.test.ITCase;

@ITCase
class SpringContextITCase {

	@Autowired
	private List<AggregationDataLoader> loaders;
	@Autowired
	private AggregationDataLoaderRegistry registry;

	@Test
	void shouldHaveLoader() {
		assertThat(getLoadersWithScopeIntern(loaders)).singleElement().isInstanceOf(AggregationDataWarehouseLoader.class);
	}

	@Test
	void shouldRegister() {
		assertThat(registry.hasLoader(AggregationMapping.Scope.INTERN)).isTrue();
	}

	private List<AggregationDataLoader> getLoadersWithScopeIntern(List<AggregationDataLoader> loaders) {
		return loaders.stream()
				.filter(loader -> loader.getScope() == AggregationMapping.Scope.INTERN)
				.toList();
	}
}
